@@ -1,15 +1,16 @@
 import base64
 from . import *
+import os
 import logging
 
 log = logging.getLogger(LOGGER_NAME)
 
 
 class Authenticator:
-    def __init__(self):
-        self.token = config.token
-        self.login = config.login
-        self.password = config.password
+    def __init__(self):       
+        self.token = os.getenv('NG_API_AUTHTOKEN')
+        self.login = os.getenv('LOGIN')
+        self.password = os.getenv('PASSWORD')
 
     def get_token(self):
         if self.token is not None:
