@@ -1,18 +1,12 @@
-from .HTTPCalller import HTTPCaller
-import urllib
 import io
+import urllib
 import zipfile
-import os,  sys
-
-# Create the logger for the SDK
 import logging
-logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
-log = logging.getLogger('GX_SDK')
 
-# logger_handler = logging.StreamHandler()
-# log.addHandler(logger_handler)
-# logger_handler.setFormatter(logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s'))
+from . import LOGGER_NAME
+from .HTTPCalller import HTTPCaller
 
+log = logging.getLogger(LOGGER_NAME)
 
 
 class DatalakeHandler:
@@ -43,7 +37,6 @@ class DatalakeHandler:
         r = self.caller.get(path)
 
         log.debug(f'{r.url} \n {r.request.headers} \n {r.json()}')
-
         return r.json()
 
     def get_info_from_id(self, file_id):
@@ -62,7 +55,6 @@ class DatalakeHandler:
 
         return r.json()
 
-
     def download_by_id(self, file_id, dest_file_name=None, save=False, unzip=False):
         '''
         Download the file according to its file_id from the datalake.
@@ -94,7 +86,6 @@ class DatalakeHandler:
             # Get the file ID from S3 service
             file_response = self.caller.get_from_S3(data_headers['Location'])
 
-
         if save:
             # Download & Save the file locally
             log.info(f'Download File by Id: {file_id}')
@@ -111,7 +102,6 @@ class DatalakeHandler:
                 log.debug('File metadata found on datalake from ID: {}'.format(file_meta))
                 dest_file_name = file_meta['fileName']
 
-
             # save the file to the current folder
             with open(dest_file_name, "wb") as input_file:
                 input_file.write(file_response.content)
@@ -131,9 +121,7 @@ class DatalakeHandler:
             log.info('File obtained from Datalake as BytesIO object')
             return io.BytesIO(file_response.content)
 
-
-
-    def download_by_name(self,  file_name, group_name, file_type=None, dest_file_name=None, save=False, unzip=False):
+    def download_by_name(self, file_name, group_name, file_type=None, dest_file_name=None, save=False, unzip=False):
         '''
         Download a file from the data lake given its name & group.
         It returns by default the most recent occurency of the file.
@@ -161,20 +149,19 @@ class DatalakeHandler:
         query = self.search_file(file_name=file_name, file_type=file_type, group_name=group_name)
         log.debug(f'Download by name: {query}')
 
+        if 'items' not in query:
+            raise ValueError('Encountered problem with downloading file : {}'.format(query['message']))
+
         if len(query['items']) == 0:
-            raise ValueError('No file {} found on group {} with type {}: {}'.format(file_name, group_name, file_type, query))
+            raise ValueError(
+                'No file {} found on group {} with type {}: {}'.format(file_name, group_name, file_type, query))
 
         else:
             # Download by ID of the found file
             fid = query['items'][0]['fid']
             return self.download_by_id(file_id=fid, dest_file_name=dest_file_name, save=save, unzip=unzip)
 
-
-
-
-
-
-    def upload_file(self, file,  group_name, file_upload_name=None, file_type='SOURCE'):
+    def upload_file(self, file, group_name, file_upload_name=None, file_type='SOURCE', partial_update=False):
         '''
         Upload the file to the datalake group with the given type (SOURCE as default)
 
@@ -195,11 +182,13 @@ class DatalakeHandler:
 
         log.info(f'Upload File with Name: {file_name} of type {file_type} to group {group_name}')
 
+        p_u = [{"name":"PARTIAL_UPDATE","value":"true"}] if partial_update is True else []
+
         # PAYLOAD for the upload of the file
         payload = {"groupName": group_name,
                    "fileName": file_name,
                    "fileType": file_type,
-                   "fields": []}
+                   "fields": p_u}
 
         log.debug(f'Payload: {payload}')
 
