@@ -1,7 +1,6 @@
 import logging
 import sys
 
-from .configuration import *
 # Set logger with proper format for backend parsing to status page
 from .constants import LOGGER_NAME
 
@@ -11,7 +10,6 @@ log = logging.Logger(LOGGER_NAME)
 logger_handler = logging.StreamHandler()
 logger_handler.setFormatter(logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s'))
 log.addHandler(logger_handler)
-config = configuration.Configuration()
 
 # Import the methods
 from .DatalakeHandler import *
